.. _api_ref:

.. currentmodule:: inequality

API reference
=============

.. _inequality_api:

Theil Inequality Measures
-------------------------

.. autosummary::
   :toctree: generated/

    inequality.theil.Theil 
    inequality.theil.TheilD
    inequality.theil.TheilDSim


Gini Inequality Measures
------------------------

.. autosummary::
   :toctree: generated/

    inequality.gini.Gini
    inequality.gini.Gini_Spatial

